from setuptools import setup

setup(
    name='codequery',
    version='0.1.0',
    description='Queries and code facts checking support for python source code',
    url='https://github.com/daltonserey/codequery',
    author='Dalton Serey',
    author_email='daltonserey@gmail.com',
    maintainer='Dalton Serey',
    maintainer_email='daltonserey@gmail.com',
    license='MIT',
    py_modules=['codequery'],
    python_requires='>3.6',
)
